@@ -2,14 +2,14 @@
  *
  *  iodbc.h
  *
- *  $Id$
+ *  $Id: iodbc.h,v 1.12 2007/10/08 13:04:32 source Exp $
  *
  *  Configuration
  *
  *  The iODBC driver manager.
  *
- *  Copyright (C) 1995 Ke Jin <kejin@empress.com>
- *  Copyright (C) 1996-2023 OpenLink Software <iodbc@openlinksw.com>
+ *  Copyright (C) 1995 by Ke Jin <kejin@empress.com>
+ *  Copyright (C) 1996-2006 by OpenLink Software <iodbc@openlinksw.com>
  *  All Rights Reserved.
  *
  *  This software is released under the terms of either of the following
@@ -81,18 +81,16 @@
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
-#elif defined (__APPLE__)
-#include "macos_config.h"
 #endif
 
 #ifndef VERSION
-#define VERSION		"3.52.16"
+#define VERSION		"3.52.6"
 #define MAJ_VERSION	"3"
 #define MIN_VERSION	"52"
 #endif
 
 #ifndef IODBC_BUILD
-#define IODBC_BUILD 16230502	/* 0001.0928 */
+#define IODBC_BUILD 6071008	/* 0001.0928 */
 #endif
 
 #if	!defined(WINDOWS) && !defined(WIN32_SYSTEM)
