@@ -1,14 +1,14 @@
 /*
  *  info.c
  *
- *  $Id$
+ *  $Id: info.c,v 1.36 2007/01/05 12:22:39 source Exp $
  *
  *  Information functions
  *
  *  The iODBC driver manager.
  *
  *  Copyright (C) 1995 by Ke Jin <kejin@empress.com>
- *  Copyright (C) 1996-2014 by OpenLink Software <iodbc@openlinksw.com>
+ *  Copyright (C) 1996-2006 by OpenLink Software <iodbc@openlinksw.com>
  *  All Rights Reserved.
  *
  *  This software is released under the terms of either of the following
@@ -727,7 +727,7 @@ SQLGetInfo_Internal (
   void * _InfoValue = NULL;
   void * infoValueOut = rgbInfoValue;
 
-  SQLPOINTER ptr = 0;
+  DWORD dword = 0;
   int size = 0, len = 0, ret = 0;
   wchar_t buf[20] = {'\0'};
 
@@ -814,20 +814,20 @@ SQLGetInfo_Internal (
   switch (fInfoType)
     {
     case SQL_DRIVER_HDBC:
-      ptr = (SQLPOINTER) (pdbc->dhdbc);
-      size = sizeof (ptr);
+      dword = (DWORD) (pdbc->dhdbc);
+      size = sizeof (dword);
       break;
 
     case SQL_DRIVER_HENV:
       penv = (ENV_t *) (pdbc->henv);
-      ptr = (SQLPOINTER) (penv->dhenv);
-      size = sizeof (ptr);
+      dword = (DWORD) (penv->dhenv);
+      size = sizeof (dword);
       break;
 
     case SQL_DRIVER_HLIB:
       penv = (ENV_t *) (pdbc->henv);
-      ptr = (SQLPOINTER) (penv->hdll);
-      size = sizeof (ptr);
+      dword = (DWORD) (penv->hdll);
+      size = sizeof (dword);
       break;
 
     case SQL_DRIVER_HSTMT:
@@ -853,8 +853,8 @@ SQLGetInfo_Internal (
 	  return SQL_ERROR;
 	}
 
-      ptr = (SQLPOINTER) (pstmt->dhstmt);
-      size = sizeof (ptr);
+      dword = (DWORD) (pstmt->dhstmt);
+      size = sizeof (dword);
       break;
 
     case SQL_DRIVER_NAME:
@@ -864,7 +864,7 @@ SQLGetInfo_Internal (
       break;
 
     default:
-      /* NOTE : this was before the switch, just move here to let some information going through */
+      /* NOTE : this was before the switch, just move here to let some informations going through */
       if (pdbc->state == en_dbc_allocated || pdbc->state == en_dbc_needdata)
 	{
 	  PUSHSQLERR (pdbc->herr, en_08003);
@@ -876,7 +876,7 @@ SQLGetInfo_Internal (
     {
       if (rgbInfoValue != NULL)
 	{
-	  rgbInfoValue = ptr;
+	  *((DWORD *) rgbInfoValue) = dword;
 	}
 
       if (pcbInfoValue != NULL)
